(async-decoder tokenizer id-chan)(async-decoder provider id-chan text-chan)Creates a decoder that asynchronously decodes singular tokens from id-chan
and puts the decoded string on the text-chan. provider is a tokenizer or any object
that can provide a tokenizer. The tokens are decoded by a stateful streaming tokenizer,
which takes care of special cases and multi-id strings.
Creates a decoder that asynchronously decodes singular tokens from `id-chan` and puts the decoded string on the `text-chan`. `provider` is a tokenizer or any object that can provide a tokenizer. The tokens are decoded by a stateful streaming tokenizer, which takes care of special cases and multi-id strings.
(async-encoder provider text-chan)(async-encoder provider text-chan ids-chan)Creates an encoder that asynchronously tokenizes textual prompts received from text-chan
and puts the sequence of tokens on the ids-chan. provider is a tokenizer or any object
that can provide a tokenizer. Currently supported tokenizers are Sentencepiece and Hugging Face Tokenizer.
Creates an encoder that asynchronously tokenizes textual prompts received from `text-chan` and puts the sequence of tokens on the `ids-chan`. `provider` is a tokenizer or any object that can provide a tokenizer. Currently supported tokenizers are Sentencepiece and Hugging Face Tokenizer.
(async-generator provider in-chan)(async-generator provider in-chan tok-chan)Creates a token generator that asynchronously generates tokens until stopped,
either internally (EOS), or externally (by closing the in-chan, or putting :stop on in-chan).
The provider determines the model and implementation technology of the token generator.
For available providers, please see technology-specific iLLaManati sub-projects.
Creates a token generator that asynchronously generates tokens until stopped, either internally (EOS), or externally (by closing the in-chan, or putting `:stop` on `in-chan`). The `provider` determines the model and implementation technology of the token generator. For available providers, please see technology-specific iLLaManati sub-projects.
(decoder)(decoder args)(decoder decoder _)(decoder decoder _ id)The token decoder step-fn compatible with core.async Flow processes. Please see the :describe map.
The token decoder step-fn compatible with core.async Flow processes. Please see the `:describe` map.
(encoder)(encoder args)(encoder tokenizer _)(encoder tokenizer _ text)The text encoder step-fn compatible with core.async Flow processes. Please see the :describe map.
The text encoder step-fn compatible with core.async Flow processes. Please see the `:describe` map.
(generator-process provider)Token generator process compatible with core.async Flow processes. provider determines the model
and implementation technology of the token generator. For available providers, please see
technology-specific iLLaManati sub-projects.
Token generator process compatible with core.async Flow processes. `provider` determines the model and implementation technology of the token generator. For available providers, please see technology-specific iLLaManati sub-projects.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |